@@ -9,7 +9,7 @@ use Net::RDAP::Registry;
 use vars qw($VERSION);
 use strict;
 
-$VERSION = 0.8;
+$VERSION = 0.9;
 
 =pod
 
@@ -307,12 +307,20 @@ sub fetch {
 			'description'	=> [ sprintf("The Content-Type of the header is '%s', should be 'application/rdap+json'", $response->header('Content-Type')) ],
 		);
 
+	} elsif (!defined($data) || 'HASH' ne ref($data)) {
+		return $self->error(
+			'url'		=> $url,
+			'errorCode'	=> 500,
+			'title'		=> 'Error parsing response body',
+			'description'	=> [ 'The response from the server is not a valid JSON object' ],
+		);
+
 	} elsif (!defined($data->{'objectClassName'})) {
 		return $self->error(
 			'url'		=> $url,
 			'errorCode'	=> 500,
 			'title'		=> "Missing 'objectClassName' property",
-			'description'	=> [ "The response from the server is missing the 'objectClassName' property." ],
+			'description'	=> [ "The response from the server is missing the 'objectClassName' property" ],
 		);
 
 	} else {
@@ -346,12 +354,30 @@ sub request {
 	return $self->ua->request($req);
 }
 
-#
-# wrapper function
-#
+=pod
+
+=head2 RDAP User Agent
+
+	# access the user agent
+	$ua = $rdap->ua;
+
+	# specify a cookie jar
+	$rdap->ua->cookie_jar('/tmp/cookies.txt');
+
+	# specify a proxy
+	$rdap->ua->proxy([qw(http https)], 'https://proxy.example.com');
+
+You can access the L<Net::RDAP::UA> object used to communicate with RDAP
+servers using the C<ua()> method. This allows you to configure additional
+HTTP features such as a file to store cookies, proxies, custom user-agent
+strings, etc.
+
+=cut
+
 sub ua {
 	my $self = shift;
 	$self->{'ua'} = Net::RDAP::UA->new if (!defined($self->{'ua'}));
+	$NET::RDAP::Registry::UA = $self->{'ua'} if (!defined($NET::RDAP::Registry::UA));
 	return $self->{'ua'};
 }
 
@@ -426,12 +452,16 @@ RDAP-related modules that all work together. They are:
 
 =back
 
+=item * L<Net::RDAP::EPPStatusMap>
+
 =item * L<Net::RDAP::Registry>
 
 =item * L<Net::RDAP::Link>
 
 =item * L<Net::RDAP::UA>
 
+=item * L<Net::RDAP::Values>
+
 =back
 
 =head1 DEPENDENCIES
@@ -468,6 +498,8 @@ RDAP-related modules that all work together. They are:
 
 =item * L<vCard>
 
+=item * L<XML::LibXML>
+
 =back
 
 =head1 REFERENCES
